@@ -1,7 +1,7 @@
 package Hits;
 
 # This file is part of the pnopaste program
-# Copyright (C) 2008-2010 Patrick Matthäi <pmatthaei@debian.org>
+# Copyright (C) 2008-2013 Patrick Matthäi <pmatthaei@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@ use lib::Database;
 sub Inc_Badword {
 	my($ID) = @_;
 
-	my $Query = 'UPDATE blacklist_word SET hits = hits + 1 WHERE id = ? LIMIT 1';
+	my $Query = 'UPDATE blacklist_word SET hits = hits + 1 WHERE id = ?';
 	$Query = $Database::dbh->prepare($Query);
 	$Query->execute($ID);
 }
@@ -27,7 +27,7 @@ sub Inc_Badword {
 sub Inc_Badhost {
 	my($ID) = @_;
 
-	my $Query = 'UPDATE blacklist_ip SET hits = hits + 1 WHERE id = ? LIMIT 1';
+	my $Query = 'UPDATE blacklist_ip SET hits = hits + 1 WHERE id = ?';
 	$Query = $Database::dbh->prepare($Query);
 	$Query->execute($ID);
 }
