@@ -1,7 +1,7 @@
 package Language;
 
 # This file is part of the pnopaste program
-# Copyright (C) 2008-2010 Patrick Matthäi <pmatthaei@debian.org>
+# Copyright (C) 2008-2013 Patrick Matthäi <pmatthaei@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -64,7 +64,10 @@ sub Set_Language {
 sub Mapping {
 	my($Lang) = @_;
 
-	if($Lang eq 'AT'){
+	if(!defined $Lang){
+		$Lang = 'EN';
+	}
+	elsif($Lang eq 'AT'){
 		$Lang = 'DE';
 	}
 
